@@ -14,20 +14,31 @@ unitfulvalue(x::Unitful.AbstractQuantity) = x
 @inline function DiffEqBase.ODE_DEFAULT_NORM(
         u::AbstractArray{
             <:Unitful.AbstractQuantity,
-            N
+            N,
         },
-        t) where {N}
-    sqrt(sum(x -> DiffEqBase.ODE_DEFAULT_NORM(x[1], x[2]),
-        zip((value(x) for x in u), Iterators.repeated(t))) / length(u))
+        t
+    ) where {N}
+    return sqrt(
+        sum(
+            x -> DiffEqBase.ODE_DEFAULT_NORM(x[1], x[2]),
+            zip((value(x) for x in u), Iterators.repeated(t))
+        ) / length(u)
+    )
 end
-@inline function DiffEqBase.ODE_DEFAULT_NORM(u::Array{<:Unitful.AbstractQuantity, N},
-        t) where {N}
-    sqrt(sum(x -> DiffEqBase.ODE_DEFAULT_NORM(x[1], x[2]),
-        zip((value(x) for x in u), Iterators.repeated(t))) / length(u))
+@inline function DiffEqBase.ODE_DEFAULT_NORM(
+        u::Array{<:Unitful.AbstractQuantity, N},
+        t
+    ) where {N}
+    return sqrt(
+        sum(
+            x -> DiffEqBase.ODE_DEFAULT_NORM(x[1], x[2]),
+            zip((value(x) for x in u), Iterators.repeated(t))
+        ) / length(u)
+    )
 end
 @inline DiffEqBase.ODE_DEFAULT_NORM(u::Unitful.AbstractQuantity, t) = abs(value(u))
 @inline function DiffEqBase.UNITLESS_ABS2(x::Unitful.AbstractQuantity)
-    real(abs2(x) / oneunit(x) * oneunit(x))
+    return real(abs2(x) / oneunit(x) * oneunit(x))
 end
 
 DiffEqBase._rate_prototype(u, t, onet) = u / unit(t)
